@@ -6,7 +6,7 @@ use warnings;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-11-23'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.026'; # VERSION
+our $VERSION = '0.027'; # VERSION
 
 our $schema = ['dirname' => {
     summary => 'Directory name, default to current directory',
@@ -15,7 +15,7 @@ our $schema = ['dirname' => {
 Note: be careful when using this schema for actions that are destructive,
 because a user can perform those actions without giving an argument (e.g. in a
 `delete-files-in` script). It is safer to use this schema when performing a
-non=destructive action (e.g. `ls`) and/or operate in dry-run mode by default.
+non-destructive action (e.g. `ls`) and/or operate in dry-run mode by default.
 
 _
 
@@ -41,7 +41,7 @@ Sah::Schema::dirname::default_curdir - Directory name, default to current direct
 
 =head1 VERSION
 
-This document describes version 0.026 of Sah::Schema::dirname::default_curdir (from Perl distribution Sah-Schemas-Path), released on 2023-11-23.
+This document describes version 0.027 of Sah::Schema::dirname::default_curdir (from Perl distribution Sah-Schemas-Path), released on 2023-11-23.
 
 =head1 SYNOPSIS
 
@@ -163,7 +163,7 @@ L<Type::Tiny> as well as L<Type::FromSah>):
 Note: be careful when using this schema for actions that are destructive,
 because a user can perform those actions without giving an argument (e.g. in a
 C<delete-files-in> script). It is safer to use this schema when performing a
-non=destructive action (e.g. C<ls>) and/or operate in dry-run mode by default.
+non-destructive action (e.g. C<ls>) and/or operate in dry-run mode by default.
 
 =head1 HOMEPAGE
 
