@@ -5,7 +5,7 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-11-23'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.026'; # VERSION
+our $VERSION = '0.027'; # VERSION
 
 our $schema = ["dirname::exists" => {
     summary => 'Directory name, must exist on the filesystem, defaults to only subdirectory in current directory (if there is one)',
@@ -18,7 +18,7 @@ single subdirectory and nothing else.
 Note: be careful when using this schema for actions that are destructive,
 because a user can perform those actions without giving an argument (e.g. in a
 `delete-files-in` script). It is safer to use this schema when performing a
-non=destructive action (e.g. `ls`) and/or operate in dry-run mode by default.
+non-destructive action (e.g. `ls`) and/or operate in dry-run mode by default.
 
 MARKDOWN
     'x.perl.default_value_rules' => ['Path::only_subdir_in_curdir'],
@@ -39,7 +39,7 @@ Sah::Schema::dirname::exists::default_only_subdir_in_curdir - Directory name, mu
 
 =head1 VERSION
 
-This document describes version 0.026 of Sah::Schema::dirname::exists::default_only_subdir_in_curdir (from Perl distribution Sah-Schemas-Path), released on 2023-11-23.
+This document describes version 0.027 of Sah::Schema::dirname::exists::default_only_subdir_in_curdir (from Perl distribution Sah-Schemas-Path), released on 2023-11-23.
 
 =head1 SYNOPSIS
 
@@ -165,7 +165,7 @@ single subdirectory and nothing else.
 Note: be careful when using this schema for actions that are destructive,
 because a user can perform those actions without giving an argument (e.g. in a
 C<delete-files-in> script). It is safer to use this schema when performing a
-non=destructive action (e.g. C<ls>) and/or operate in dry-run mode by default.
+non-destructive action (e.g. C<ls>) and/or operate in dry-run mode by default.
 
 =head1 HOMEPAGE
 
