@@ -5,7 +5,7 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-11-23'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.026'; # VERSION
+our $VERSION = '0.027'; # VERSION
 
 our $schema = ["filename" => {
     summary => 'File name, defaults to only file in current directory (if there is one) (subdirectories ignored)',
@@ -22,7 +22,7 @@ does not ignore subdirectories. Thus, if a directory only contains `file1` and
 Note: be careful when using this schema for actions that are destructive,
 because a user can perform those actions without giving an argument (e.g. in a
 `delete-file` script). It is safer to use this schema when performing a
-non=destructive action (e.g. `checksum`) and/or operate in dry-run mode by
+non-destructive action (e.g. `checksum`) and/or operate in dry-run mode by
 default.
 
 MARKDOWN
@@ -44,7 +44,7 @@ Sah::Schema::filename::default_only_file_not_dir_in_curdir - File name, defaults
 
 =head1 VERSION
 
-This document describes version 0.026 of Sah::Schema::filename::default_only_file_not_dir_in_curdir (from Perl distribution Sah-Schemas-Path), released on 2023-11-23.
+This document describes version 0.027 of Sah::Schema::filename::default_only_file_not_dir_in_curdir (from Perl distribution Sah-Schemas-Path), released on 2023-11-23.
 
 =head1 SYNOPSIS
 
@@ -174,7 +174,7 @@ C<subdir1>, then that other schema will not return C<file1> but this schema will
 Note: be careful when using this schema for actions that are destructive,
 because a user can perform those actions without giving an argument (e.g. in a
 C<delete-file> script). It is safer to use this schema when performing a
-non=destructive action (e.g. C<checksum>) and/or operate in dry-run mode by
+non-destructive action (e.g. C<checksum>) and/or operate in dry-run mode by
 default.
 
 =head1 HOMEPAGE
