@@ -5,7 +5,7 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-11-23'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.026'; # VERSION
+our $VERSION = '0.027'; # VERSION
 
 our $schema = ["str" => {
     summary => 'Filesystem base file name on a Unix system',
@@ -46,7 +46,7 @@ Sah::Schema::filename::unix::basename - Filesystem base file name on a Unix syst
 
 =head1 VERSION
 
-This document describes version 0.026 of Sah::Schema::filename::unix::basename (from Perl distribution Sah-Schemas-Path), released on 2023-11-23.
+This document describes version 0.027 of Sah::Schema::filename::unix::basename (from Perl distribution Sah-Schemas-Path), released on 2023-11-23.
 
 =head1 SYNOPSIS
 
@@ -82,7 +82,7 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
- $data = "foo\0";
+ $data = "foo/bar";
  my $errmsg = $validator->($data); # => "Must match regex pattern \\A(?:[^/\\0]{1,255})\\z"
 
 Often a schema has coercion rule or default value rules, so after validation the
@@ -97,8 +97,8 @@ validated value will be different from the original. To return the validated
  my $res = $validator->($data); # => ["","foo"]
  
  # a sample invalid data
- $data = "foo\0";
- my $res = $validator->($data); # => ["Must match regex pattern \\A(?:[^/\\0]{1,255})\\z","foo\0"]
+ $data = "foo/bar";
+ my $res = $validator->($data); # => ["Must match regex pattern \\A(?:[^/\\0]{1,255})\\z","foo/bar"]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
