@@ -5,7 +5,7 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-11-23'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.026'; # VERSION
+our $VERSION = '0.027'; # VERSION
 
 1;
 # ABSTRACT: Schemas related to filesystem path
@@ -22,7 +22,7 @@ Sah::Schemas::Path - Schemas related to filesystem path
 
 =head1 VERSION
 
-This document describes version 0.026 of Sah::Schemas::Path (from Perl distribution Sah-Schemas-Path), released on 2023-11-23.
+This document describes version 0.027 of Sah::Schemas::Path (from Perl distribution Sah-Schemas-Path), released on 2023-11-23.
 
 =head1 DESCRIPTION
 
@@ -81,7 +81,7 @@ Directory name, default to current directory.
 Note: be careful when using this schema for actions that are destructive,
 because a user can perform those actions without giving an argument (e.g. in a
 C<delete-files-in> script). It is safer to use this schema when performing a
-non=destructive action (e.g. C<ls>) and/or operate in dry-run mode by default.
+non-destructive action (e.g. C<ls>) and/or operate in dry-run mode by default.
 
 
 =item * L<dirname::default_curdir_abs|Sah::Schema::dirname::default_curdir_abs>
@@ -91,7 +91,7 @@ Directory name, default to current directory (absolutified).
 Note: be careful when using this schema for actions that are destructive,
 because a user can perform those actions without giving an argument (e.g. in a
 C<delete-files-in> script). It is safer to use this schema when performing a
-non=destructive action (e.g. C<ls>) and/or operate in dry-run mode by default.
+non-destructive action (e.g. C<ls>) and/or operate in dry-run mode by default.
 
 
 =item * L<dirname::default_only_subdir_in_curdir|Sah::Schema::dirname::default_only_subdir_in_curdir>
@@ -110,7 +110,7 @@ return a default value.
 Note: be careful when using this schema for actions that are destructive,
 because a user can perform those actions without giving an argument (e.g. in a
 C<delete-files-in> script). It is safer to use this schema when performing a
-non=destructive action (e.g. C<ls>) and/or operate in dry-run mode by default.
+non-destructive action (e.g. C<ls>) and/or operate in dry-run mode by default.
 
 
 =item * L<dirname::default_only_subdir_not_file_in_curdir|Sah::Schema::dirname::default_only_subdir_not_file_in_curdir>
@@ -129,7 +129,7 @@ will.
 Note: be careful when using this schema for actions that are destructive,
 because a user can perform those actions without giving an argument (e.g. in a
 C<delete-files-in> script). It is safer to use this schema when performing a
-non=destructive action (e.g. C<ls>) and/or operate in dry-run mode by default.
+non-destructive action (e.g. C<ls>) and/or operate in dry-run mode by default.
 
 
 =item * L<dirname::exists|Sah::Schema::dirname::exists>
@@ -151,7 +151,7 @@ single subdirectory and nothing else.
 Note: be careful when using this schema for actions that are destructive,
 because a user can perform those actions without giving an argument (e.g. in a
 C<delete-files-in> script). It is safer to use this schema when performing a
-non=destructive action (e.g. C<ls>) and/or operate in dry-run mode by default.
+non-destructive action (e.g. C<ls>) and/or operate in dry-run mode by default.
 
 
 =item * L<dirname::not_exists|Sah::Schema::dirname::not_exists>
@@ -235,7 +235,7 @@ not return a default value.
 Note: be careful when using this schema for actions that are destructive,
 because a user can perform those actions without giving an argument (e.g. in a
 C<delete-file> script). It is safer to use this schema when performing a
-non=destructive action (e.g. C<checksum>) and/or operate in dry-run mode by
+non-destructive action (e.g. C<checksum>) and/or operate in dry-run mode by
 default.
 
 
@@ -254,7 +254,7 @@ C<subdir1>, then that other schema will not return C<file1> but this schema will
 Note: be careful when using this schema for actions that are destructive,
 because a user can perform those actions without giving an argument (e.g. in a
 C<delete-file> script). It is safer to use this schema when performing a
-non=destructive action (e.g. C<checksum>) and/or operate in dry-run mode by
+non-destructive action (e.g. C<checksum>) and/or operate in dry-run mode by
 default.
 
 
@@ -277,7 +277,7 @@ plain file and nothing else.
 Note: be careful when using this schema for actions that are destructive,
 because a user can perform those actions without giving an argument (e.g. in a
 C<delete-file> script). It is safer to use this schema when performing a
-non=destructive action (e.g. C<checksum>) and/or operate in dry-run mode by
+non-destructive action (e.g. C<checksum>) and/or operate in dry-run mode by
 default.
 
 
